@@ -8,8 +8,9 @@
 (custom-add-loads 'eldoc '("eldoc"))
 (custom-add-loads 'ielm '("ielm"))
 (custom-add-loads 'hide-copyleft '("hide-copyleft"))
-(custom-add-loads 'lisp '("elp" "find-func" "ielm"))
+(custom-add-loads 'lisp '("checkdoc" "elp" "find-func" "ielm"))
 (custom-add-loads 'elp '("elp"))
+(custom-add-loads 'checkdoc '("checkdoc"))
 (custom-add-loads 'find-function '("find-func"))
 (custom-add-loads 'matching '("hide-copyleft"))
 
