@@ -57,6 +57,9 @@
 ;; buffer, go to the group buffer, and press `M-x clear-profiling-info'
 ;; followed by `M-x profile-key-sequence RET SPC'.
 
+;; A convenient higher level profiling tool is `compile-and-profile',
+;; which automatically byte-compiles code to be profiled.
+;; This makes the profiling results more meaningful.
 
 ;;; Code:
 
@@ -185,4 +188,14 @@ The function returns the profiling info."
   (profile
     (mapc 'dispatch-event keys)))
 
+;;;###autoload
+(defmacro compile-and-profile (&rest forms)
+  "Byte compile FORMS, profile the execution, and pretty-print the results."
+  `(progn
+     (clear-profiling-info)
+     (flet ((compiled-code-being-profiled () ,@forms))
+       (byte-compile 'compiled-code-being-profiled)
+       (call-interactively 'profile-results
+			   (profile (compiled-code-being-profiled))))))
+
 ;;; profile.el ends here
